EvmDataReader

Struct EvmDataReader 

pub struct EvmDataReader<'a> { /* private fields */ }
Wrapper around an EVM input slice, helping to parse it. Provide functions to parse common types.

Implementations

Source

impl<'a> EvmDataReader<'a>

pub fn new(input: &'a [u8]) -> Self

Create a new input parser.

pub fn expect_arguments(&self, args: usize) -> EvmResult

Check the input has at least the correct amount of arguments before the end (32 bytes values).

pub fn read<T: EvmData>(&mut self) -> EvmResult<T>

Read data from the input.

pub fn read_raw_bytes(&mut self, len: usize) -> EvmResult<&[u8]>

Read raw bytes from the input. Doesn’t handle any alignement checks, prefer using read instead of possible. Returns an error if trying to parse out of bounds.

pub fn read_selector<T>(&mut self) -> EvmResult<T>
where T: TryFromPrimitive<Primitive = u32>,

Parse (4 bytes) selector. Returns an error if trying to parse out of bounds.