pub struct EvmDataWriter { /* private fields */ }Expand description
Help build an EVM input/output data.
Implementations
Sourceimpl EvmDataWriter
impl EvmDataWriter
Sourcepub fn write_raw_bytes(self, value: &[u8]) -> Self
pub fn write_raw_bytes(self, value: &[u8]) -> Self
Write arbitrary bytes.
Doesn’t handle any alignement checks, prefer using write instead if possible.
Sourcepub fn write_selector<T: Into<u32>>(self, value: T) -> Self
pub fn write_selector<T: Into<u32>>(self, value: T) -> Self
Write a selector.
The provided type must impl Into<u32>.
Doesn’t handle any alignement checks, should be used only when adding the initial
selector of a Solidity call data.