Gasometer

Struct Gasometer 

pub struct Gasometer { /* private fields */ }
Custom Gasometer to record costs in precompiles. It is advised to record known costs as early as possible to avoid unecessary computations if there is an Out of Gas.

Implementations

Source

impl Gasometer

pub fn new(target_gas: Option<u64>) -> Self

Create a new Gasometer with provided gas limit. None is no limit.

pub fn used_gas(&self) -> u64

Get used gas.

pub fn record_cost(&mut self, cost: u64) -> EvmResult

Record cost, and return error if it goes out of gas.

pub fn record_log_costs_manual( &mut self, topics: usize, data_len: usize, ) -> EvmResult

Record cost of a log manualy. This can be useful to record log costs early when their content have static size.

pub fn record_log_costs(&mut self, logs: &[Log]) -> EvmResult

Record cost of logs.

pub fn remaining_gas(&self) -> EvmResult<Option<u64>>

Compute remaining gas. Returns error if out of gas. Returns None if no gas limit.